<?php 
if( ! isset( $content_width ) )
    $content_width = 625;

function ar_setup() {
    load_theme_textdomain( 'ar', get_template_directory() . '/langs' );
    add_editor_style();
    add_theme_support( 'automatic-feed-links' );
    add_theme_support( 'post-formats', array( 'aside', 'image', 'link', 'quote', 'status' ) );
    register_nav_menu( 'menu', __( 'Main Menu', 'ar' ) );
    $cb = array(
        'default-color' => '1a0608',
        'default-image'  => ''
    );
    add_theme_support( 'custom-background', $cb );
    add_theme_support( 'post-thumbnails' );
    set_post_thumbnail_size( 625, 9999 );
}
add_action( 'after_setup_theme', 'ar_setup' );

require( get_template_directory() . '/inc/custom-header.php' );

function ar_scripts() {
    wp_enqueue_style( 'ar-style', get_stylesheet_uri() );

    wp_enqueue_script( 'ar-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '1.0', true );

    wp_enqueue_script( 'ar-ie-html5', get_template_directory_uri() . '/js/html5.js', array(), '1.0', true );

    wp_enqueue_script( 'ar-it-css-media-queries', get_template_directory_uri() . '/js/css3-mediaqueries.js', array(), '1.0', true );
}
add_action( 'wp_enqueue_scripts', 'ar_scripts' );

function ar_scripts_styles() {
    if( is_singular() && comments_open() && get_option( 'thread_comments' ) )
        wp_enqueue_script( 'comment-reply' );
    wp_enqueue_script( 'ar-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '1.0', true );
    if( 'off' !== _x( 'on', 'PTSansRegular font: on or off', 'ar' ) ) {
        $subsets = 'latin,latin-ext';
        $subset = _x( 'no-subset', 'PTSansRegular font: add new subset (greek, cyrillic, vietnamese)', 'ar' );
        if( 'cyrillic' == $subset )
            $subsets .= ',cyrillic,cyrillic-ext';
        elseif( 'greek' == $subset )
            $subsets .= ',greek,greek-ext';
        elseif( 'vietnamese' == $subset )
            $subsets .= ',vietnamese';
        $query_args = array(
            'family' => 'PTSansRegular:400italic,700',
            'subset' => $subsets
        );
        wp_enqueue_style( 'ar-fonts' );
    }
    wp_enqueue_style( 'ar-style', get_stylesheet_uri() );
}
add_action( 'wp_enqueue_scripts', 'ar_scripts_styles' );

function ar_wp_title( $title, $sep ) {
    global $paged, $page;
    if( is_feed() )
        return $title;
    $title .= get_bloginfo( 'name' );
    $site_description = get_bloginfo( 'description', 'display' );
    if( $site_description && ( is_home() || is_front_page() ) )
        $title = "$title $sep $site_description";
    if( $paged >= 2 || $page >= 2 )
        $title = "$title $sep " . sprintf( __( 'Page %s', 'ar' ), max( $paged, $page ) );
    return $title;
}
add_filter( 'wp_title', 'ar_wp_title', 10, 2 );

function ar_page_menu_args( $args ) {
    if( ! isset( $args['show_home'] ) )
        $args['show_home'] = true;
    return $args;
}
add_filter( 'wp_page_menu_args', 'ar_page_menu_args' );

function ar_widgets_init() {
    register_sidebar(
        array(
            'name' => __( 'Meta widget', 'ar' ),
            'id' => 'sidebar-1',
            'description' => __( 'Appears on posts and pages except the optional Front Page template, which has its own widgets', 'ar' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>'
        )
    );
    register_sidebar(
        array(
            'name' => __( 'Tag Cloud widget', 'ar' ),
            'id' => 'sidebar-2',
            'description' => __( 'Appears when using the optional Front Page template with a page set as Static Front Page', 'ar' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>'
        )
    );
    register_sidebar(
        array(
            'name' => __( 'Various widgets', 'ar' ),
            'id' => 'sidebar-3',
            'description' => __( 'Appears when using the optional Front Page template with a page set as Static Front Page', 'ar' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>'
        )
    );
    register_sidebar(
        array(
            'name' => __( 'Search Form Widget Area', 'ar' ),
            'id' => 'sidebar-4',
            'description' => __( 'Search Form Widget Area', 'ar' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>'
        )
    );
}
add_action( 'widgets_init', 'ar_widgets_init' );

if( ! function_exists( 'ar_content_nav' ) ) : 
function ar_content_nav( $nav_id ) {
    global $wp_query;
    $html_id = esc_attr( $nav_id );
    if( $wp_query->max_num_pages > 1 ) : ?>
        <nav id="<?php echo $nav_id; ?>" class="navigation">
            <h3 class="accessibility"><?php _e( 'Post navigation', 'ar' ); ?></h3>
            <ul>
                <li class="prev-link alignleft"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'ar' )); ?></li>
                <li class="next-link alignright"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'ar' )); ?></li>
            </ul>
        </nav>
    <?php endif;
}
endif;

if( ! function_exists( 'ar_comment' ) ) : 
function ar_comment( $comment, $args, $depth ) {
    $GLOBALS['comment'] = $comment;
    switch ( $comment->comment_type ) :
        case 'pingback' :
        case 'trackback' : ?>
    <li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
        <p><?php _e( 'Pingback:', 'ar' ); comment_author_link(); edit_comment_link( __( 'Edit', 'ar' ), '<span class="edit-link">', '</span>' ); ?></p>
    <?php break;
        default :
        global $post; ?>
    <li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
        <article id="comment-<?php comment_ID(); ?>" class="comment">
            <header class="comment-meta comment-author vcard">
                <?php echo get_avatar( $comment, 44 );
                    printf( '<cite class="fn">%1$s %2$s</cite>',
                        get_comment_author_link(), (
                        $comment->user_id === $post->post_author) ? '<span> ' . __( 'Post author', 'ar' ) . '</span>' : ''
                    );
                    printf( '<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
                        esc_url( get_comment_link( $comment->comment_ID ) ),
                        get_comment_time( 'c' ),
                        sprintf( __( '%1$s at %2$s', 'ar' ), get_comment_date(), get_comment_time() )
                    ); ?>
            </header>
            <?php if( '0' == $comment->comment_approved ) : ?>
                <p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'ar' ); ?></p>
            <?php endif; ?>
            <section class="comment-content comment">
                <?php comment_text();
                edit_comment_link( __( 'Edit', 'ar' ), '<p class="edit-link">', '</p>' ); ?>
            </section>
            <div class="reply">
                <?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'ar' ), 'after' => ' <span>&darr;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
            </div>
        </article>
    <?php break;
    endswitch;
}
endif;

if( ! function_exists( 'ar_entry_meta' ) ) :
function ar_entry_meta() {
    $categories_list = get_the_category_list( __( ', ', 'ar' ) );
    $tag_list = get_the_tag_list( '', __( ', ', 'ar' ) );
    $date = sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><time class="post-date" datetime="%3$s">%4$s</time></a>',
        esc_url( get_permalink() ),
        esc_attr( get_the_time() ),
        esc_attr( get_the_date( 'c' ) ),
        esc_html( get_the_date() )
    );
    $author = sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
        esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
        esc_attr( sprintf( __( 'View all posts by %s', 'ar' ), get_the_author() ) ),
        get_the_author()
    );
    if( $tag_list ) {
        $utility_text = __( '<span class="cats">Categories: %1$s </span><span class="tags">Tags: %2$s </span><span class="date">%3$s </span> <span class="by-author">Author %4$s</span>', 'ar' );
    } elseif( $categories_list ) {
        $utility_text = __( '<span class="cats">Categories: %1$s </span><span class="tags">%3$s</span><span class="by-author">Author: %4$s</span>', 'ar' );
    } else {
        $utility_text = __( '%3$s <span class="by-author">Author: %4$s</span>', 'ar' );
    }
    printf(
        $utility_text,
        $categories_list,
        $tag_list,
        $date,
        $author
    );
}
endif;

function ar_body_class( $classes ) {
    $background_color = get_background_color();
    if( ! is_page_template( 'page-templates/full-width.php' ) ) {
        foreach( $classes as $key => $value ) {
            if($value == 'full-width' ) unset( $classes[$key] );
        }
    }
    return $classes;
    if( is_page_template( 'page-templates/front-page.php' ) ) {
        $classes[] = 'template-front-page';
        if( has_post_thumbnail() )
            $classes[] = 'has-post-thumbnail';
    }
    if( empty( $background_color ) )
        $classes[] = 'custom-background-empty';
    elseif( in_array( $background_color, array( 'fff', '1a0608' ) ) )
        $classes[] = 'custom-background-white';
    if( wp_style_is( 'ar-fonts', 'queue' ) )
        $classes[] = 'custom-font-enabled';
    if( ! is_multi_author() )
        $classes[] = 'single-author';
    return $classes;
}
add_filter( 'body_class', 'ar_body_class' );

function ar_content_width() {
    if( is_page_template( 'page-templates/full-width.php' ) || is_attachment() || ! is_active_sidebar( 'sidebar-1' ) ) {
        global $content_width;
        $content_width = 960;
    }
}
add_action( 'template_redirect', 'ar_content_width' );

function ar_customize_register( $wp_customize ) {
    $wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
    $wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
}
add_action( 'customize_register', 'ar_customize_register' );

function ar_customize_preview_js() {
    wp_enqueue_script( 'ar-customizer', get_template_directory_uri() . '/js/theme-customizer.js', array( 'customize-preview' ), '20120827', TRUE );
}
add_action( 'customize_preview_init', 'ar_customize_preview_js' );